#
# spec file for package python-PyKCS11
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-PyKCS11
Version:        1.5.17
Release:        1.2
Summary:        A Full PKCS#11 wrapper for Python
License:        GPL-2.0-or-later
URL:            https://github.com/LudovicRousseau/PyKCS11
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module asn1crypto}
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
BuildRequires:  softhsm-devel
BuildRequires:  swig
%python_subpackages

%description
A Full PKCS#11 wrapper for Python

%prep
%autosetup -n PyKCS11-%{version}

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export $(python3 get_PYKCS11LIB.py)
# Unfortunately the test suite is irrecovabily broken
# gh#LudovicRousseau/PyKCS11#115
# %%pyunittest_arch discover -v test

%files %{python_files}
%doc Changes.txt README.md
%license COPYING
%{python_sitearch}/PyKCS11
%{python_sitearch}/PyKCS11-%{version}*-info

%changelog
* Wed Oct 16 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.5.17:
  * Add AES in counter mode support (CKM_AES_CTR)
  * Add simple derivation mechanisms support (CMK_CONCATENATE_*)
  * Fix reference counting in PyKCS11Lib.load()
  * remove python 2 support from ckbytelist
  * minor improvements
* Sun Jun  2 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the spec
- Unfortunately, the tests are still not run
  (gh#LudovicRousseau/PyKCS11#115).
* Fri May 24 2024 Richard Rahl <rrahl0@disroot.org>
- update to 1.5.16:
  * add support of CKA_MODIFIABLE and CKA_DESTROYABLE attributes
  * minor improvments
* Fri May 17 2024 Richard Rahl <rrahl0@disroot.org>
- update to 1.5.15:
  * Fix an exception when PYKCS11LIB is not defined
  * Correctly fix swig 4.2.0 issue
  * cache PKCS#11 dll name after it's been succsessfully loaded
  * Fix a problem when the library load failed
- switch to github url, as pypi doesn't have the new version
* Tue Mar 26 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
